module REPL where

import Gargantext.API.Admin.Types (HasSettings)
import Gargantext.API.Dev (runCmdReplEasy)
import Gargantext.API.Errors.Types (BackendInternalError)
import Gargantext.Core.NLP (HasNLPServer)
import Gargantext.Core.NodeStory.Types (HasNodeStory)
import Gargantext.Core.Text.Corpus.Query qualified as Q
import Gargantext.Core.Types.Individu (User (..))
import Gargantext.Database.Action.Corpus (makeSubcorpusFromQuery)
import Gargantext.Database.Admin.Types.Node (CorpusId)
import Gargantext.Database.Prelude (DbCmd')
import Gargantext.Database.Query.Tree.Error (HasTreeError)
import Gargantext.Prelude



execText :: IO (Maybe CorpusId)
execText = runCmdReplEasy $ testSubcorpusFunction "user1" 133 "information" False

testSubcorpusFunction ::
  forall env m. ( DbCmd'       env BackendInternalError m
                , HasNodeStory env BackendInternalError m
                , HasNLPServer env
                , HasNLPServer env
                , HasTreeError     BackendInternalError
                , HasSettings  env
                )
  => Text     -- ^ Username
  -> CorpusId -- ^ Parent corpus ID
  -> Text     -- ^ The query, in text form
  -> Bool     -- ^ Whether to reuse parent term list (True) or compute a new one
              --   based only on the documents in the subcorpus (False)
  -> m (Maybe CorpusId)
testSubcorpusFunction username parentId queryText reuseParentList =
  let eitherQuery = Q.parseQuery . Q.RawQuery $ queryText in
  case eitherQuery of
    Left _      -> return Nothing -- putStrLn ("Error parsing query " <> queryText) >> return Nothing -- TODO emit an actual error
    Right query -> Just <$> makeSubcorpusFromQuery (UserName username) parentId query reuseParentList

